pub struct ComputeNodeOpts {Show 18 fields
pub listen_addr: String,
pub advertise_addr: Option<String>,
pub prometheus_listener_addr: String,
pub meta_address: MetaAddressStrategy,
pub config_path: String,
pub total_memory_bytes: usize,
pub reserved_memory_bytes: Option<usize>,
pub memory_manager_target_bytes: Option<usize>,
pub parallelism: usize,
pub resource_group: String,
pub role: Role,
pub metrics_level: Option<MetricLevel>,
pub data_file_cache_dir: Option<String>,
pub meta_file_cache_dir: Option<String>,
pub async_stack_trace: Option<AsyncStackTraceOption>,
pub heap_profiling_dir: Option<String>,
pub connector_rpc_endpoint: Option<String>,
pub temp_secret_file_dir: String,
}Expand description
Command-line arguments for compute-node.
Fields
listen_addr: StringThe address that this service listens to. Usually the localhost + desired port.
advertise_addr: Option<String>The address for contacting this instance of the service.
This would be synonymous with the service’s “public address”
or “identifying address”.
Optional, we will use listen_addr if not specified.
prometheus_listener_addr: StringWe will start a http server at this address via MetricsManager.
Then the prometheus instance will poll the metrics from this address.
meta_address: MetaAddressStrategyconfig_path: StringThe path of risingwave.toml configuration file.
If empty, default configuration values will be used.
total_memory_bytes: usizeTotal available memory for the compute node in bytes. Used by both computing and storage.
reserved_memory_bytes: Option<usize>Reserved memory for the compute node in bytes.
If not set, a portion (default to 30% for the first 16GB and 20% for the rest)
for the total_memory_bytes will be used as the reserved memory.
The total memory compute and storage can use is total_memory_bytes - reserved_memory_bytes.
memory_manager_target_bytes: Option<usize>Target memory usage for Memory Manager.
If not set, the default value is total_memory_bytes - reserved_memory_bytes
It’s strongly recommended to set it for standalone deployment.
Why need this?
Our crate::memory::manager::MemoryManager works by reading the memory statistics from
Jemalloc. This is fine when running the compute node alone; while for standalone mode,
the memory usage of all nodes are counted. Thus, we need to pass a reasonable total
usage so that the memory is kept around this value.
parallelism: usizeThe parallelism that the compute node will register to the scheduler of the meta service.
resource_group: StringResource group for scheduling, default value is “default”
role: RoleDecides whether the compute node can be used for streaming and serving.
metrics_level: Option<MetricLevel>Used for control the metrics level, similar to log level.
level = 0: disable metrics level > 0: enable metrics
data_file_cache_dir: Option<String>Path to data file cache data directory. Left empty to disable file cache.
meta_file_cache_dir: Option<String>Path to meta file cache data directory. Left empty to disable file cache.
async_stack_trace: Option<AsyncStackTraceOption>Enable async stack tracing through await-tree for risectl.
heap_profiling_dir: Option<String>Enable heap profile dump when memory usage is high.
connector_rpc_endpoint: Option<String>connector node has been deprecated.
Endpoint of the connector node.
temp_secret_file_dir: StringThe path of the temp secret file directory.